import dotenv from "dotenv";
import { RouteManager, RouteMessages, createServer } from "server";
import { checkEnvironmentVariables } from "utils";
import NodeManager from "./node/nodeManager";
import ProxyRoute from "./routes/proxy";
import { initSecrets } from "./secrets";

dotenv.config(); // load .env file

// Check environment variables
const envVarsValid = checkEnvironmentVariables("API_PORT", "INFISICAL_TOKEN");
if (!envVarsValid) {
  process.exit(1);
}

/**
 * The node manager for all of the loaded nodes
 */
export const nodeManager = new NodeManager();

const server = createServer({
  port: process.env.API_PORT || 3000,
  onLoaded: async () => {
    await initSecrets(process.env.INFISICAL_TOKEN!); // Load the infisical secrets

    const routeManager = new RouteManager();
    routeManager.addRoute(new ProxyRoute());

    server.all("*", (req, res) => {
      // Handle all paths to the proxy route
      const routes = routeManager.getRoutes();
      if (!routes || routes.length === 0 || !routes[0]) {
        res.status(500).json(RouteMessages.internalServerError("No routes"));
        return;
      }
      routes[0].handle(req, res);
    });
  },
});
